[asterisk-commits] trunk r12344 - /trunk/utils.c

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Tue Mar 7 10:55:35 MST 2006


Author: oej
Date: Tue Mar  7 11:55:33 2006
New Revision: 12344

URL: http://svn.digium.com/view/asterisk?rev=12344&view=rev
Log:
Doxygen changes

Modified:
    trunk/utils.c

Modified: trunk/utils.c
URL: http://svn.digium.com/view/asterisk/trunk/utils.c?rev=12344&r1=12343&r2=12344&view=diff
==============================================================================
--- trunk/utils.c (original)
+++ trunk/utils.c Tue Mar  7 11:55:33 2006
@@ -64,13 +64,13 @@
 
 #if defined(__FreeBSD__) || defined(__OpenBSD__) || defined( __NetBSD__ ) || defined(__APPLE__) || defined(__CYGWIN__)
 
-/* duh? ERANGE value copied from web... */
-#define ERANGE 34
+#define ERANGE 34	/*!< duh? ERANGE value copied from web... */
 #undef gethostbyname
 
 AST_MUTEX_DEFINE_STATIC(__mutex);
 
-/* Recursive replacement for gethostbyname for BSD-based systems.  This
+/*! \brief Recursive replacement for gethostbyname for BSD-based systems.
+\note This
 routine is derived from code originally written and placed in the public 
 domain by Enzo Michelangeli <em at em.no-ip.com> */
 
@@ -282,7 +282,7 @@
 	return(test_errors);          /* return 0 on success. */
 }
 
-/*! \brief ast_md5_hash: Produce 32 char MD5 hash of value. ---*/
+/*! \brief Produce 32 char MD5 hash of value. */
 void ast_md5_hash(char *output, char *input)
 {
 	struct MD5Context md5;
@@ -298,7 +298,7 @@
 		ptr += sprintf(ptr, "%2.2x", digest[x]);
 }
 
-/*! \brief ast_sha1_hash: Produce 40 char SHA1 hash of value. ---*/
+/*! \brief Produce 40 char SHA1 hash of value. */
 void ast_sha1_hash(char *output, char *input)
 {
 	struct SHA1Context sha;
@@ -316,6 +316,7 @@
 		ptr += sprintf(ptr, "%2.2x", Message_Digest[x]);
 }
 
+/*! \brief decode BASE64 encoded text */
 int ast_base64decode(unsigned char *dst, const char *src, int max)
 {
 	int cnt = 0;
@@ -354,6 +355,7 @@
 	return cnt;
 }
 
+/*! \brief encode text to BASE64 coding */
 int ast_base64encode(char *dst, const unsigned char *src, int srclen, int max)
 {
 	int cnt = 0;
@@ -431,8 +433,8 @@
 #endif
 }
 
-/*! \brief  ast_uri_encode: Turn text string to URI-encoded %XX version ---*/
-/* 	At this point, we're converting from ISO-8859-x (8-bit), not UTF8
+/*! \brief  ast_uri_encode: Turn text string to URI-encoded %XX version
+\note 	At this point, we're converting from ISO-8859-x (8-bit), not UTF8
 	as in the SIP protocol spec 
 	If doreserved == 1 we will convert reserved characters also.
 	RFC 2396, section 2.4
@@ -473,7 +475,7 @@
 	return outbuf;
 }
 
-/*! \brief  ast_uri_decode: Decode SIP URI, URN, URL (overwrite the string)  ---*/
+/*! \brief  ast_uri_decode: Decode SIP URI, URN, URL (overwrite the string)  */
 void ast_uri_decode(char *s) 
 {
 	char *o;
@@ -773,10 +775,10 @@
 	                                 /* max value of a "long int" */
 #endif
 
-/*
+/*! \brief
  * Convert a string to a quad integer.
  *
  * Ignores `locale' stuff.  Assumes that the upper and lower case
  * alphabets and digits are each contiguous.
  */
 uint64_t strtoq(const char *nptr, char **endptr, int base)
@@ -866,7 +868,7 @@
 
 #ifndef HAVE_GETLOADAVG
 #ifdef linux
-/* Alternative method of getting load avg on Linux only */
+/*! \brief Alternative method of getting load avg on Linux only */
 int getloadavg(double *list, int nelem)
 {
 	FILE *LOADAVG;
@@ -886,7 +888,7 @@
 	return res;
 }
 #else /* !linux */
-/* Return something that won't cancel the call, but still return -1, in case
+/*! \brief Return something that won't cancel the call, but still return -1, in case
  * we correct the implementation to check return value */
 int getloadavg(double *list, int nelem)
 {
@@ -900,7 +902,7 @@
 #endif /* linux */
 #endif /* !defined(_BSD_SOURCE) */
 
-/* glibc puts a lock inside random(3), so that the results are thread-safe.
+/*! \brief glibc puts a lock inside random(3), so that the results are thread-safe.
  * BSD libc (and others) do not. */
 #ifndef linux
 
@@ -1052,7 +1054,7 @@
 }
 
 
-/*
+/*! \brief
  * get values from config variables.
  */
 int ast_get_time_t(const char *src, time_t *dst, time_t _default, int *consumed)
@@ -773,10 +775,10 @@
  * Convert a string to a quad integer.
  *
- * Ignores `locale' stuff.  Assumes that the upper and lower case
+ * \note Ignores `locale' stuff.  Assumes that the upper and lower case
  * alphabets and digits are each contiguous.
  */



More information about the asterisk-commits mailing list